==> hermes-2.3.4-788283a3.tar.gz: hermes-2.3.4-788283a3/app/jobs/update_score_job.rb <==
class UpdateScoreJob < ActiveJob::Base
  queue_as :low

  def perform(from_name, batch_ids, from_id)
    i=0
    total = batch_ids.length
    case from_name
    when 'housing_request'
      applicant_id = from_id
    when 'housing_offer'
      offer_id = from_id
    end
    found_or_created_scores = []
    batch_ids.each do |batch_elt_id|
      case from_name
      when 'housing_request'
        offer_id = batch_elt_id
      when 'housing_offer'
        applicant_id = batch_elt_id
      end
      offer = Hermes::HousingOffer.only(:id).find_by(id: offer_id)
      applicant = Hermes::Applicant.only(:id).find_by(id: applicant_id)
      cond = offer && applicant
      next unless cond

      score = Hermes::Score.find_or_create_by(housing_offer_id: offer_id, applicant_id: applicant_id, is_active: true) do
        # Enter here only if score was created
        offer.notify(key: NOTIFICATION_KEYS[:housing_offer][:new_eligible_offer], channels: ['email'], sender: offer.lessor)
      end
      score.process
      Rails.logger.info "calc score for offer [#{i}/#{total}] #{offer_id} applicant : #{applicant_id} score : #{score.id}"
      found_or_created_scores << batch_elt_id.to_s
    end
    offer_filter, applicant_filter = case from_name
                                    when 'housing_request'
                                      [{ :$nin => found_or_created_scores }, from_id]
                                    when 'housing_offer'
                                      [from_id, { :$nin => found_or_created_scores }]
                                    end
    other_scores = Hermes::Score.where(housing_offer_id: offer_filter, applicant_id: applicant_filter)

    other_scores.set(is_active: false, updated_at: DateTime.current)
    offers_true_filter = offer_filter
    if offers_true_filter.is_a?(Hash)
      offers_true_filter[:$in] = offers_true_filter[:$nin]
      offers_true_filter.delete(:$nin)
    end
    Hermes::HousingOffer.where(id: offer_filter).pluck(:id).each do |offer_id|
      UpdateOfferEligibleNbJob.perform_later(offer_id.to_s)
    end

    Rails.logger.info "#{other_scores.count} scores have been set to inactive for #{from_name}:#{from_id}"
  end
end

==> hermes-2.3.4-37375790.tar.gz: hermes-2.3.4-37375790/app/jobs/update_score_job.rb <==
class UpdateScoreJob < ActiveJob::Base
  queue_as :low

  def perform(from_name, batch_ids, from_id)
    i=0
    total = batch_ids.length
    case from_name
    when 'housing_request'
      applicant_id = from_id
    when 'housing_offer'
      offer_id = from_id
    end
    found_or_created_scores = []
    batch_ids.each do |batch_elt_id|
      case from_name
      when 'housing_request'
        offer_id = batch_elt_id
      when 'housing_offer'
        applicant_id = batch_elt_id
      end
      # :effort_rate is needed because it used in an after_initialize, it throw error if not included in attibutes list
      offer = Hermes::HousingOffer.only(:id, :effort_rate).find_by(id: offer_id)
      applicant = Hermes::Applicant.only(:id).find_by(id: applicant_id)
      cond = offer && applicant
      next unless cond

      score = Hermes::Score.find_or_create_by(housing_offer_id: offer_id, applicant_id: applicant_id, is_active: true) do
        # Enter here only if score was created
        offer.notify(key: NOTIFICATION_KEYS[:housing_offer][:new_eligible_offer], channels: ['email'], sender: offer.lessor)
      end
      score.process
      Rails.logger.info "calc score for offer [#{i}/#{total}] #{offer_id} applicant : #{applicant_id} score : #{score.id}"
      found_or_created_scores << batch_elt_id.to_s
    end
    offer_filter, applicant_filter = case from_name
                                    when 'housing_request'
                                      [{ :$nin => found_or_created_scores }, from_id]
                                    when 'housing_offer'
                                      [from_id, { :$nin => found_or_created_scores }]
                                    end
    other_scores = Hermes::Score.where(housing_offer_id: offer_filter, applicant_id: applicant_filter)

    other_scores.set(is_active: false, updated_at: DateTime.current)
    offers_true_filter = offer_filter
    if offers_true_filter.is_a?(Hash)
      offers_true_filter[:$in] = offers_true_filter[:$nin]
      offers_true_filter.delete(:$nin)
    end
    Hermes::HousingOffer.where(id: offer_filter).pluck(:id).each do |offer_id|
      UpdateOfferEligibleNbJob.perform_later(offer_id.to_s)
    end

    Rails.logger.info "#{other_scores.count} scores have been set to inactive for #{from_name}:#{from_id}"
  end
end
